==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/bookmarks/bookmarkstoolviewfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BOOKMARKSTOOLVIEWFACTORY_H
#define BOOKMARKSTOOLVIEWFACTORY_H

// lib
#include <kasten/okteta/oktetakastencontrollers_export.h>
// Kasten gui
#include <kasten/abstracttoolviewfactory.h>

namespace Kasten {

class OKTETAKASTENCONTROLLERS_EXPORT BookmarksToolViewFactory : public AbstractToolViewFactory
{
public:
    BookmarksToolViewFactory();
    ~BookmarksToolViewFactory() override;

public: // AbstractToolViewFactory API
    AbstractToolView* create(AbstractTool* tool) override;

    QString iconName() const override;
    QString title() const override;
    QString id() const override;
    SidePosition defaultPosition() const override;
};

}

#endif

==> okteta_4.13.0.orig.tar.xz: okteta-4.13.0/kasten/controllers/view/bookmarks/bookmarkstoolviewfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BOOKMARKSTOOLVIEWFACTORY_H
#define BOOKMARKSTOOLVIEWFACTORY_H

// lib
#include "oktetakastencontrollers_export.h"
// Kasten core
#include <abstracttoolviewfactory.h>


namespace Kasten2
{

class OKTETAKASTENCONTROLLERS_EXPORT BookmarksToolViewFactory : public AbstractToolViewFactory
{
  public:
    BookmarksToolViewFactory();
    virtual ~BookmarksToolViewFactory();

  public: // AbstractToolViewFactory API
    virtual AbstractToolView* create( AbstractTool* tool );

    virtual QString iconName() const;
    virtual QString title() const;
    virtual QString id() const;
    virtual SidePosition defaultPosition() const;
};

}

#endif
